{*****************************************************************************
  Copyright: Copyright by yu wei, 2001 - 2002
  Unit Name:    KWizard
  Author:       yu wei
  Email:        william_yuwei@yahoo.com
  Date:         Febrary 02, 2002
  Last Updated: Febrary 02, 2002
  Time:         14:35:34
  Purpose:      Demo for TKWizardRouteMap
  History:
  ---------------------------------------------------------------------------
  Date(mm/dd/yy)   Comments
  ---------------------------------------------------------------------------
  02/02/2002       Initial create
******************************************************************************}

unit MyRouteMap;

interface

uses Windows, Classes, Messages, Graphics, StdCtrls, KWizard;

type
  TYWizardRouteMapControl = class(TKWizardRouteMapControl)
  private
    FItemHeight: Integer;
    procedure SetItemHeight(Value: Integer);
  protected
    function PageAtPos(Pos: TPoint): Integer; override;
    procedure WizardPageAdded(const APage: TKWizardCustomPage); override;
    procedure WizardPageDeleted(const APage: TKWizardCustomPage); override;
    procedure WizardPageUpdated(const APage: TKWizardCustomPage); override;
    procedure WizardPageActivated(const APage: TKWizardCustomPage); override;
    procedure WizardPageMoved(const APage: TKWizardCustomPage;
      const OldIndex: Integer); override;
    procedure Paint; override;
  public
    constructor Create(AOwner: TComponent); override;
  published
    property ItemHeight: Integer
      read FItemHeight write SetItemHeight;
    property Align;
    property Color;
    property Font;
  end;

procedure Register;

implementation

procedure Register;
begin
  RegisterComponents('K Wizard', [TYWizardRouteMapControl]);
end;

{ TYWizardRouteMapControl }

constructor TYWizardRouteMapControl.Create(AOwner: TComponent);
begin
  inherited;
  FItemHeight := 16;
  Color := clWindow;
end;

function TYWizardRouteMapControl.PageAtPos(Pos: TPoint): Integer;
var
  Count: Integer;
  ARect: TRect;
begin
  ARect := ClientRect;
  InflateRect(ARect, -1, -1);
  if PtInRect(ARect, Pos) then
  begin
    Count := PageCount;
    ARect := Bounds(ARect.Left, ARect.Top, ARect.Right - ARect.Left, FItemHeight);
    Result := 0;
    while Result < Count do
    begin
      if PtInRect(ARect, Pos) then Exit;
      OffsetRect(ARect, 0, FItemHeight);
      Inc(Result);
    end;
  end;
  Result := -1;
end;

procedure TYWizardRouteMapControl.Paint;
var
  ARect, TextRect: TRect;
  i: Integer;
  AColor: TColor;
  AFont: TFont;
begin
  ARect := ClientRect;
  with Canvas do
  begin
    Brush.Color := Color;
    Brush.Style := bsSolid;
    Pen.Color := clBtnShadow;
    Pen.Width := 1;
    Pen.Style := psSolid;
    Rectangle(ARect);
  end;
  InflateRect(ARect, -1, -1);
  AFont := TFont.Create;
  try
    AFont.Assign(Font);
    ARect := Bounds(ARect.Left, ARect.Top, ARect.Right - ARect.Left, FItemHeight);
    for i := 0 to PageCount - 1 do
    begin
      AColor := Color;
      if i = PageIndex then
      begin
        AColor := clHighlight;
        AFont.Color := clHighlightText;
      end
      else if not Pages[i].Enabled then
        AFont.Color := clBtnShadow
      else
        AFont.Color := clBtnText;
      TextRect := ARect;
      try
        Canvas.Brush.Color := AColor;
        Canvas.FillRect(TextRect);
        Canvas.Brush.Style := bsClear;
        Canvas.Font.Assign(AFont);
        DrawText(Canvas.Handle, PChar(Pages[i].Caption), -1, TextRect,
          DT_LEFT or DT_SINGLELINE or DT_VCENTER);
      finally
        OffsetRect(ARect, 0, FItemHeight);
      end;
    end;
  finally
    AFont.Free;
  end;
end;

procedure TYWizardRouteMapControl.SetItemHeight(Value: Integer);
begin
  if FItemHeight <> Value then
  begin
    FItemHeight := Value;
    Invalidate;
  end;
end;

procedure TYWizardRouteMapControl.WizardPageActivated(
  const APage: TKWizardCustomPage);
begin
  Invalidate;
end;

procedure TYWizardRouteMapControl.WizardPageAdded(
  const APage: TKWizardCustomPage);
begin
  Invalidate;
end;

procedure TYWizardRouteMapControl.WizardPageDeleted(
  const APage: TKWizardCustomPage);
begin
  Invalidate;
end;

procedure TYWizardRouteMapControl.WizardPageMoved(
  const APage: TKWizardCustomPage; const OldIndex: Integer);
begin
  Invalidate;
end;

procedure TYWizardRouteMapControl.WizardPageUpdated(
  const APage: TKWizardCustomPage);
begin
  Invalidate;
end;

end.
